@@ -81,9 +81,9 @@ class Note(_NoteOptional):
     visible_user_ids: Optional[List[str]]
     via_mobile: Optional[bool]
     local_only: Optional[bool]
-    no_extract_mentions: Optional[bool]
-    no_extract_hashtags: Optional[bool]
-    no_extract_emojis: Optional[bool]
+    extract_mentions: Optional[bool]
+    extract_hashtags: Optional[bool]
+    extract_emojis: Optional[bool]
     preview: Optional[bool]
     media_ids: Optional[List[str]]
     renote: Optional[Renote]
